@@ -166,8 +166,7 @@ Index <- R6::R6Class(
             use_series(indicators) %>%
             use_series(adjclose) %>%
             extract2(1) %>%
-            use_series(adjclose) %>%
-            unlist()
+            use_series(adjclose)
 
           result$adj_close <- adj_close
 
